@@ -9,7 +9,18 @@
 #include <liqbase/liqcell_easyrun.h>
 #include <liqbase/liqcell_easyhandler.h>
 
-
+// 20090701_234724 lcuk :
+// 20090701_234725 lcuk :
+// 20090701_234725 lcuk :
+// 20090701_234725 lcuk :
+// 20090701_234725 lcuk :
+// 20090701_234726 lcuk :
+// 20090701_234726 lcuk :
+// 20090701_234726 lcuk :
+// 20090701_234726 lcuk :
+// 20090701_234727 lcuk :
+// 20090701_234727 lcuk :
+// 20090701_234727 lcuk : todo replace plus/minus with function to show users or show my event 
 
 
 
@@ -38,7 +49,7 @@
 	}
 	
 	
-	static int caldayhead_click(liqcell *self, liqcellclickeventargs *args, void *context)
+	static int caldayhead_click(liqcell *self, liqcellclickeventargs *args, void *daybody)
 	{
 		// 20090413_155053 lcuk : disabling zoom into a day for now
 		// it should select the day - like the original liqgraffiti did
@@ -48,7 +59,7 @@
 		//args->newdialogtoopen = self;//liqcell_child_lookup( self, "body" );
 		//args->newdialogtoopen = liqcell_child_lookup( self, "body" );
 
-		liqcell *day = liqcell_getlinkparent(self);
+		liqcell *day = daybody;//liqcell_getlinkparent(self);
 		
 		if(!day)return -1;
 		
@@ -133,6 +144,9 @@
 
 		//
 		liqcell *body = liqcell_quickcreatevis(daykey,NULL,        x,y,w,h);
+		
+		
+		liqcell_handleradd_withcontext(body,    "click",   caldayhead_click,body);
 
 			liqcell_propsets(body,"calendardate",daykey);
 			
@@ -158,13 +172,13 @@
 			//###############################################################
 			// now, make sure we add a header to the day
 			
-			liqcell *head = liqcell_quickcreatevis("head",NULL,        0,0,       dayw,fh);
-			liqcell_propseti(    head,"textalign",1);
+			liqcell *head = liqcell_quickcreatevis("head",NULL,        0,0,       dayw*0.95,fh);
+			//liqcell_propseti(    head,"textalign",1);
 			liqcell_setfont(     head, font  );  //liqfont_cache_getttf("/usr/share/fonts/nokia/nosnb.ttf", (24), 0) );
 			liqcell_setcaption(  head,caption);
 			
 			
-			liqcell_handleradd(head,    "click",   caldayhead_click);
+			//liqcell_handleradd_withcontext(head,    "click",   caldayhead_click,body);
 
 
 			if(istoday)
@@ -186,13 +200,14 @@
 			{
 				// first day of the month has an additional label
 
-				liqcell *tit = liqcell_quickcreatevis("monthname",NULL,        dayw*0.1,0,       dayw*0.9,fh);
+				liqcell *tit = liqcell_quickcreatevis("monthname",NULL,        dayw*0.1,0,       dayw*0.85,fh);
 
 				strftime(buff, 64, "%B", dayts);
 				liqcell_propseti(  tit,"textalign",0);
 				liqcell_setfont(   tit, liqfont_hold(font)  );  //liqfont_cache_getttf("/usr/share/fonts/nokia/nosnb.ttf", (24), 0) );
 				liqcell_setcaption(  tit,buff);
 				liqcell_propsets(  tit, "textcolor", "rgb(0,255,0)" );
+				liqcell_propseti(    tit,"textalign",2);
 
 				liqcell_child_append( head,tit );
 			}
@@ -201,7 +216,7 @@
 
 			//###############################################################
 			// now, add the entry cell (and setup to load in a sketch related..)
-			liqcell *view = liqcell_quickcreatevis("view",NULL,        0,fh,       dayw,dayh-fh);
+			liqcell *view = liqcell_quickcreatevis("view",NULL,        0,fh,       dayw * 0.95,(dayh-fh)*0.95);
 
 			if(istoday)
 			{
@@ -238,7 +253,7 @@
 			liqcell_child_append( body,view );
 
 
-			liqcell_handleradd(body,    "click",   calday_click);
+			//liqcell_handleradd(body,    "click",   calday_click);
 			
 			
 		return body;
@@ -420,15 +435,15 @@ liqcell *liqcalendar_create()
 		//! create toolbar
 		liqcell *tbar = uitoolcol_create("tools","tools",
 				uitoolitem_create( "reset",     "reset",         "media/quickicons/stock_refresh.png",    toolitem_click,self),
-				uitoolitem_create( "delete", "delete",     "media/quickicons/gtk-remove.png",           toolitem_click,self),
-				uitoolitem_create( "add",    "add",        "media/quickicons/add.png",              toolitem_click,self),
-				uitoolitem_create( "edit", "edit",     "media/quickicons/package_graphics.png",           toolitem_click,self),
+				//uitoolitem_create( "delete", "delete",     "media/quickicons/gtk-remove.png",           toolitem_click,self),
+				//uitoolitem_create( "add",    "add",        "media/quickicons/add.png",              toolitem_click,self),
+				//uitoolitem_create( "edit", "edit",     "media/quickicons/package_graphics.png",           toolitem_click,self),
 				//uitoolitem_create( "close",  "close",      "media/quickicons/gtk-close.png",    toolitem_click),
 				//uitoolitem_create( "back",   "back",       "media/quickicons/back.png",              toolitem_click,self),
 				NULL);
 		
 		
-		liqcell_setrect(tbar, 0,56,56,480-56-56);
+		liqcell_setrect(tbar, 0,56-56,56,480-56-56+56);
 
 		liqcell_child_append( self, tbar );
 
