@@ -26,6 +26,157 @@ static int monitor_run(liqcell *context);
 //##################################################################### liqrecentsketches :: by gary birkett 
 //#####################################################################
 //#####################################################################
+/*
+
+	static int liqrecentsketches_sketchitem_click(liqcell *self, liqcellclickeventargs *args, liqcell *liqrecentsketches)
+	{
+		//liqapp_log("general click");
+		//args->newdialogtoopen = self;
+        if(liqcell_getselected(self))
+        {
+			liqcell_setselected(self,0);
+			//liqcell_propremoves(self, "textcolor"   );
+			liqcell_propremoves(self, "backcolor"   );
+			liqcell_propremoves(self, "bordercolor" );
+        }
+        else
+        {
+			liqcell_setselected(self,1);
+			//liqcell_propsets(self, "textcolor",   "rgb(0,255,0)" );
+			liqcell_propsets(self, "backcolor",   "rgb(0,40,0)" );
+			liqcell_propsets(self, "bordercolor", "rgb(0,80,0)" );
+        }
+		return 1;
+	}
+
+ */
+	
+	int liqrecentsketches_sketchitem_click(liqcell *self, liqcellclickeventargs *args, void *context)
+	{
+		liqapp_log("hello click edit!");
+		//liqcell *mydialog = quickdialog_create();
+		//liqcell_easyrun(mydialog);
+		//liqcell_release(mydialog);
+
+		char *sketchfilename  = liqcell_propgets(self,"sketchfilename",NULL);		
+		if(!sketchfilename) return -1;
+		
+		liqsketch *mysketch=liqsketch_newfromfile(sketchfilename);//   liqcell_getsketch(self);
+		if(!mysketch)return -1;
+		
+		
+		liqcell * top = liqcell_quickcreatevis("liqtop1", "liqtop", 0,0, 800,480);
+		
+		liqcell_setsketch(top, mysketch );
+		
+		
+		args->newdialogtoopen = top;
+		
+
+		return 1;
+	}	
+	
+
+
+static int liqrecentsketches_sketch_insert(liqcell *self,char *filenamebuffer)
+{
+	liqcell *body = liqcell_child_lookup( self,"body");
+
+	struct pagefilename pfn;
+	
+	if(	(pagefilename_breakapart(&pfn,filenamebuffer) == 0) )
+	{
+		
+		char buf[FILENAME_MAX];			snprintf(buf,sizeof(buf),"%s%s",pfn.filedate,pfn.filetitle);
+		
+		//liqapp_log("ins 1 %s",filenamebuffer);
+		// valid file		
+		char b[255]={0};
+		snprintf(b,5,"%s",pfn.filedate); b[4]='\0';
+		liqcell *xy=liqcell_child_lookup(body,b);
+		if(!xy)
+		{
+			//liqapp_log("ins 2 %s",filenamebuffer);
+			xy=liqcell_quickcreatevis(b,"year",  0,0, (self->w),self->h/15);
+			liqcell_child_insertsortedbyname(body,xy,0);
+			//snprintf(b,5,"%s",pfn.filedate); b[4]='\0';
+			//brk=addframe(xy,b,(self->w),self->h/15);				// year break tile
+			//brk->style=odd;
+		}
+		
+		//liqapp_log("ins 3 %s",filenamebuffer);
+		
+		
+			snprintf(b,3,"%s",&pfn.filedate[4]); b[2]='\0';
+			liqcell *xm=liqcell_child_lookup(xy,b);
+			if(!xm)
+			{
+				//liqapp_log("ins 4 %s",filenamebuffer);
+				xm=liqcell_quickcreatevis(b,"month",  0,0, (self->w),self->h/15);
+				liqcell_child_insertsortedbyname(xy,xm,0);
+				//snprintf(b,7,"%s",pfn.filedate); b[6]='\0';
+				//brk=addframe(xm,b,(self->w),self->h/15);			// month break tile
+				//brk->style=odd;
+			}
+			
+			//liqapp_log("ins 5 %s",filenamebuffer);
+			
+				snprintf(b,3,"%s",&pfn.filedate[6]); b[2]='\0';
+				liqcell *xd=liqcell_child_lookup(xm,b);
+				if(!xd)
+				{
+					//liqapp_log("ins 6 %s",filenamebuffer);
+					xd=liqcell_quickcreatevis(b,"day",  0,0, (self->w),self->h/15);
+					liqcell_child_insertsortedbyname(xm,xd,0);
+					
+					//liqapp_log("ins 7 %s",filenamebuffer);
+					// add title header
+
+					snprintf(b,10,"_%s",pfn.filedate); b[9]='\0';
+					liqcell *brk=liqcell_quickcreatevis(b,"label",  0,0, (self->w),self->h/15);
+
+
+					liqcell_setfont(	brk, liqfont_cache_getttf("/usr/share/fonts/nokia/nosnb.ttf", (24), 0) );
+					
+					snprintf(b,9,"%s",pfn.filedate); b[8]='\0';
+					
+					liqcell_setcaption(brk, b );
+					liqcell_propsets(  brk, "textcolor", "rgb(255,255,255)" );
+					liqcell_propsets(  brk, "backcolor", "rgb(0,0,100)");
+					liqcell_propseti(  brk, "textalign", 0 );
+
+					liqcell_child_append(xd,brk);
+				}
+				
+				//liqapp_log("ins 8 %s",filenamebuffer);
+				
+
+				liqcell *c = liqcell_quickcreatevis(buf,   "sketch",   0,0,(self->w/5),(self->h/4)    );
+				liqcell_propseti(c,"lockaspect",1);
+				liqcell_propsets(c,"sketchfilename",filenamebuffer);
+				liqcell_handleradd_withcontext(c,"click",liqrecentsketches_sketchitem_click,self);
+				
+				
+				liqcell_child_insertsortedbyname( xd, c,0);
+				
+				//liqapp_log("ins 9 %s",filenamebuffer);
+				
+				liqcell_setsize(xd, self->w, self->h/15 );
+				liqcell_child_arrange_autoflow(xd);
+			liqcell_child_arrange_easycol(xm);			
+		liqcell_child_arrange_easycol(xy);
+				
+		liqcell_child_arrange_easycol(body);	
+	}
+}
+
+
+
+	
+
+
+
+
 
 static int liqrecentsketches_sketch_add(liqcell *self,char *filenamebuffer)
 {
@@ -41,8 +192,9 @@ static int liqrecentsketches_sketch_add(liqcell *self,char *filenamebuffer)
 	
 	if(	(pagefilename_breakapart(&pfn,filenamebuffer) == 0) )
 	{
-		
-		
+		liqrecentsketches_sketch_insert(self,filenamebuffer);
+		return 0;
+/*		
 		char buf[FILENAME_MAX];			snprintf(buf,sizeof(buf),"%s%s",pfn.filedate,pfn.filetitle);
 
 		liqcell *body = liqcell_child_lookup( self,"body");
@@ -50,13 +202,30 @@ static int liqrecentsketches_sketch_add(liqcell *self,char *filenamebuffer)
 						liqcell *c = liqcell_quickcreatevis(buf,   "sketch",   1,1,1,1    );
 						liqcell_propseti(c,"lockaspect",1);
 						liqcell_propsets(c,"sketchfilename",filenamebuffer);
+						
+						
+						//#########################################
+						liqapp_log("name: %s",pfn.fileuser);
+						char fn[FILENAME_MAX];
+							snprintf(fn,sizeof(fn),"media/avatars/%s.png",pfn.fileuser);
+						if(!liqapp_fileexists(fn))
+						{
+							snprintf(fn,sizeof(fn),"media/avatars/%s.jpg",pfn.fileuser);
+						}
+						if(liqapp_fileexists(fn))
+						{
+							liqcell *p = liqcell_quickcreatevis(fn,   "user",   0,0,42,42    );
+							liqcell_propseti(p,"lockaspect",1);
+							liqcell_propsets(p,"imagefilename",fn);
+							liqcell_child_insert( c, p);
+						}
 
 						liqcell_child_insertsortedbyname( body, c,0);
-						
-						
 						liqcell_setsize(body,self->w,self->h);
 						liqcell_child_arrange_makegrid(body,3,3);
-	}					
+ */
+	}
+	return 0;
 }
 
 
@@ -124,6 +293,10 @@ static liqcell *quickdialog_create()
 
 static int liqcell_scan_folder_for_images(liqcell *self,char *path)
 {
+	
+	liqcell *body = liqcell_child_lookup( self,"body");
+	
+	
 		char *widgetpath = path;
 		DIR           *	dir_p;
 		struct dirent *	dir_entry_p;
@@ -171,6 +344,9 @@ static int liqcell_scan_folder_for_images(liqcell *self,char *path)
 				if(	stristr(ft,"liq.") && (pagefilename_breakapart(&pfn,ft) == 0) )
 				{
 					
+					liqrecentsketches_sketch_insert(self,fn);
+					
+				/*	
 					
 
 					//if(	pagefilename_breakapart(&pfn,ft) == 0)
@@ -187,8 +363,29 @@ static int liqcell_scan_folder_for_images(liqcell *self,char *path)
 						liqcell_propseti(c,"lockaspect",1);
 						liqcell_propsets(c,"sketchfilename",fn);
 
-						liqcell_child_insertsortedbyname( self, c,0);
+						//#########################################
+						//liqapp_log("name: %s",pfn.fileuser);
+						char fn[FILENAME_MAX];
+							snprintf(fn,sizeof(fn),"media/avatars/%s.png",pfn.fileuser);
+						if(!liqapp_fileexists(fn))
+						{
+							snprintf(fn,sizeof(fn),"media/avatars/%s.jpg",pfn.fileuser);
+						}
+						if(liqapp_fileexists(fn))
+						{
+							liqcell *p = liqcell_quickcreatevis(fn,   "user",   0,0,42,42    );
+							liqcell_propseti(p,"lockaspect",1);
+							liqcell_propsets(p,"imagefilename",fn);
+							liqcell_child_insert( c, p);
+						}
+
+
+						liqcell_child_insertsortedbyname( body, c,0);
 					}
+					
+					
+				*/
+					
 				}
 			}
 		}
@@ -226,10 +423,10 @@ if(liqapp_pathexists(buf))
 	
 		liqcell *body = liqcell_quickcreatevis("body","frame",0 ,0,   self->w,self->h);
 
-		liqcell_scan_folder_for_images(body,buf);
 		
 		liqcell_child_insert( self, body );
 		
+		liqcell_scan_folder_for_images(self,buf);
 		
 		liqcell_propsets(  self, "monitorpath" , buf);
 		//liqcell_propsets(  self, "watchpattern" , "liq.*");
@@ -237,7 +434,7 @@ if(liqapp_pathexists(buf))
 		int cnt=0;
 		liqcell *c=NULL;
 
-		liqcell_child_arrange_makegrid(body,3,3);
+		//liqcell_child_arrange_makegrid(body,3,3);
 
 		c=liqcell_lastchild(body);
 
@@ -265,6 +462,17 @@ if(liqapp_pathexists(buf))
 
 }
 
+
+		//############################# title:label
+		liqcell *title = liqcell_quickcreatevis("title", "label", 0,0, 200, 50);
+		liqcell_setfont(	title, liqfont_cache_getttf("/usr/share/fonts/nokia/nosnb.ttf", (29), 0) );
+		liqcell_setcaption(title, "Sketches" );
+		liqcell_propsets(  title, "imagefilename", "media/titlebanner_left.png" );
+		liqcell_propsets(  title, "textcolor", "rgb(255,255,0)" );
+		//liqcell_propsets(  title, "backcolor", "rgb(0,0,60)" );
+		liqcell_propseti(  title, "textalign", 0 );
+		liqcell_child_append(  self, title);
+
 	}
 	
 	return self;
@@ -319,16 +527,12 @@ if(liqapp_pathexists(buf))
 #define BUFF_SIZE ((sizeof(struct inotify_event)+FILENAME_MAX)*32)
 
 
-
-
 static void monitor_get_event(int fd, const char * target,liqcell *context)
 {
    ssize_t len=0, i = 0;
    char action[81+FILENAME_MAX] = {0};
    char buff[BUFF_SIZE] = {0};
-
 	//liqapp_log("inotify_getevent reading from '%s'",target);
-
    len = read (fd, buff, BUFF_SIZE);
    
    while (i < len)
@@ -339,58 +543,13 @@ static void monitor_get_event(int fd, const char * target,liqcell *context)
 	  
 	  if ( (pevent->len) )
 	  {
-		
-		
-		snprintf(action,sizeof(action),"%s/%s",target,pevent->name);
-		
+		snprintf(action,sizeof(action),"%s/%s",target,pevent->name);	
 		// dealing with a file
 		  if(pevent->mask & IN_CLOSE_WRITE)
 			liqrecentsketches_sketch_add(context,action);
-		//  if(pevent->mask & IN_CREATE)
-		//    liqrecentsketches_sketch_add(context,pevent->name);
 	  }
-/*
-      if (pevent->len) 
-         strcpy (action, pevent->name);
-      else
-         strcpy (action, target);
-    
-      if (pevent->mask & IN_ACCESS) 
-         strcat(action, " was read");
-      if (pevent->mask & IN_ATTRIB) 
-         strcat(action, " Metadata changed");
-      if (pevent->mask & IN_CLOSE_WRITE) 
-         strcat(action, " opened for writing was closed");
-      if (pevent->mask & IN_CLOSE_NOWRITE) 
-         strcat(action, " not opened for writing was closed");
-      if (pevent->mask & IN_CREATE) 
-         strcat(action, " created in watched directory");
-      if (pevent->mask & IN_DELETE) 
-         strcat(action, " deleted from watched directory");
-      if (pevent->mask & IN_DELETE_SELF) 
-         strcat(action, "Watched file/directory was itself deleted");
-      if (pevent->mask & IN_MODIFY) 
-         strcat(action, " was modified");
-      if (pevent->mask & IN_MOVE_SELF) 
-         strcat(action, "Watched file/directory was itself moved");
-      if (pevent->mask & IN_MOVED_FROM) 
-         strcat(action, " moved out of watched directory");
-      if (pevent->mask & IN_MOVED_TO) 
-         strcat(action, " moved into watched directory");
-      if (pevent->mask & IN_OPEN) 
-         strcat(action, " was opened");
-
-	  liqfilemonitor_showmsg(liqfilemonitor,action);
-*/	  
-	  
-	  
-
-
-	  
       i += sizeof(struct inotify_event) + pevent->len;
-
    }
-
 } 
 
 
